:mod:`kwant.linalg` -- Linear algebra routines
==============================================

.. module:: kwant.linalg

This package wraps some selected LAPACK functionality not available via NumPy
and also contains a Python-wrapper for MUMPS.  It also has several algorithms
for finding approximately orthonormal lattice bases. It is meant for internal
use by Kwant itself, but of course nothing prevents you from using it directly.

The documentation of this package is not included here on purpose in order not
to add too many things to this reference.  Please consult the source code
directly.
